%define _disable_ld_no_undefined %{nil}

%global            _hardened_build 1

%global with_nfsidmap 1


# Conditionally enable some FSALs, disable others.
#
# 1. rpmbuild accepts these options (gpfs as example):
#    --with gpfs
#    --without gpfs

%define on_off_switch() %%{?with_%1:ON}%%{!?with_%1:OFF}

# A few explanation about %%bcond_with and %%bcond_without
# /!\ be careful: this syntax can be quite messy
# %%bcond_with means you add a "--with" option, default = without this feature
# %%bcond_without adds a"--without" so the feature is enabled by default

%bcond_without nullfs
%global use_fsal_null %{on_off_switch nullfs}

%bcond_with gpfs
%global use_fsal_gpfs %{on_off_switch gpfs}

%bcond_without xfs
%global use_fsal_xfs %{on_off_switch xfs}

%ifarch armv5tl
%bcond_with ceph
%else
%bcond_without ceph
%endif
%global use_fsal_ceph %{on_off_switch ceph}

%bcond_with lustre
%global use_fsal_lustre %{on_off_switch lustre}

%bcond_with shook
%global use_fsal_shook %{on_off_switch shook}

# Disabled by default, as glusterfs was dropped in mga6 as unmaintained
%bcond_with gluster
%global use_fsal_gluster %{on_off_switch gluster}

%bcond_with hpss
%global use_fsal_hpss %{on_off_switch hpss}

%bcond_with panfs
%global use_fsal_panfs %{on_off_switch panfs}

%bcond_with pt
%global use_fsal_pt %{on_off_switch pt}

%bcond_with rdma
%global use_rdma %{on_off_switch rdma}

%bcond_without jemalloc

%bcond_with lustre_up
%global use_lustre_up %{on_off_switch lustre_up}

%bcond_with lttng
%global use_lttng %{on_off_switch lttng}

%bcond_without utils
%global use_utils %{on_off_switch utils}

%bcond_without gui_utils
%global use_gui_utils %{on_off_switch gui_utils}

%bcond_without system_ntirpc
%global use_system_ntirpc %{on_off_switch system_ntirpc}

%global dev_version %{lua: extraver = string.gsub('', '%-', '.'); print(extraver) }

Name:		nfs-ganesha
Version:	2.4.1
Release:	%mkrel 3
Summary:	NFS-Ganesha is a NFS Server running in user space
Group:		System/Servers
License:	LGPLv3+
Url:		https://github.com/nfs-ganesha/nfs-ganesha/wiki
Source0:	https://github.com/%{name}/%{name}/archive/V%{version}/%{name}-%{version}%{dev_version}.tar.gz
%if %{with gluster}
Patch0:		nfs-ganesha-2.4.1-glusterfs-api.patch
%endif

BuildRequires:	cmake
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	pkgconfig
BuildRequires:	krb5-devel
BuildRequires:	dbus-devel
BuildRequires:	libcap-devel
BuildRequires:	libblkid-devel
BuildRequires:	libuuid-devel
%if %{with system_ntirpc}
BuildRequires:	pkgconfig(libntirpc) >= 1.4.1
%endif
Requires:	dbus
Requires:	nfs-utils
%if %{with_nfsidmap}
BuildRequires:	libnfsidmap-devel
%else
BuildRequires:	nfs-utils-lib-devel
%endif
%if %{with rdma}
BuildRequires:	libmooshika-devel >= 0.6-0
%endif
%if %{with jemalloc}
BuildRequires:	jemalloc-devel
%endif
%if %{with lustre_up}
BuildRequires: lcap-devel >= 0.1-0
%endif

BuildRequires: systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# Use CMake variables

%description
nfs-ganesha : NFS-GANESHA is a NFS Server running in user space.
It comes with various back-end modules (called FSALs) provided as
shared objects to support different file systems and name-spaces.

%package mount-9P
Summary: a 9p mount helper
Group: System/Servers

%description mount-9P
This package contains the mount.9P script that clients can use
to simplify mounting to NFS-GANESHA. This is a 9p mount helper.

%package vfs
Summary: The NFS-GANESHA's VFS FSAL
Group: System/Servers
BuildRequires: libattr-devel
Requires: nfs-ganesha = %{version}-%{release}

%description vfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support VFS based filesystems.

%package proxy
Summary: The NFS-GANESHA's PROXY FSAL
Group: System/Servers
BuildRequires: libattr-devel
Requires: nfs-ganesha = %{version}-%{release}

%description proxy
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PROXY based filesystems.

%if %{with utils}
%package utils
Summary: The NFS-GANESHA's util scripts
Group: System/Servers
Requires:	dbus-python, python-gobject
%if %{with gui_utils} 
BuildRequires:	python-qt4-devel
Requires:	python-qt4
%endif
BuildRequires:  pkgconfig(python2)
Requires: nfs-ganesha = %{version}-%{release}, python

%description utils
This package contains utility scripts for managing the NFS-GANESHA server.
%endif

%if %{with lttng}
%package lttng
Summary: The NFS-GANESHA's library for use with LTTng
Group: System/Servers
BuildRequires: lttng-ust-devel >= 2.3
Requires: nfs-ganesha = %{version}-%{release}, lttng-tools >= 2.3,  lttng-ust >= 2.3

%description lttng
This package contains the libganesha_trace.so library. When preloaded
to the ganesha.nfsd server, it makes it possible to trace using LTTng.
%endif

# Option packages start here. use "rpmbuild --with lustre" (or equivalent)
# for activating this part of the spec file

# NULL
%if %{with nullfs}
%package nullfs
Summary: The NFS-GANESHA's NULLFS Stackable FSAL
Group: System/Servers
Requires: nfs-ganesha = %{version}-%{release}

%description nullfs
This package contains a Stackable FSAL shared object to
be used with NFS-Ganesha. This is mostly a template for future (more sophisticated)
stackable FSALs.
%endif

# GPFS
%if %{with gpfs}
%package gpfs
Summary: The NFS-GANESHA's GPFS FSAL
Group: System/Servers
Requires: nfs-ganesha = %{version}-%{release}

%description gpfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support GPFS backend.
%endif

# CEPH
%if %{with ceph}
%package ceph
Summary: The NFS-GANESHA's CEPH FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	ceph >= 1:10.2.0
BuildRequires:	libcephfs1-devel >= 1:10.2.0

%description ceph
This package contains a FSAL shared object to
be used with NFS-Ganesha to support CEPH.
%endif

# LUSTRE
%if %{with lustre}
%package lustre
Summary: The NFS-GANESHA's LUSTRE FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	lustre
BuildRequires:	libattr-devel lustre

%description lustre
This package contains a FSAL shared object to
be used with NFS-Ganesha to support LUSTRE.
%endif

# SHOOK
%if %{with shook}
%package shook
Summary: The NFS-GANESHA's LUSTRE/SHOOK FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
Requires:	lustre shook-client
BuildRequires:	libattr-devel lustre shook-devel

%description shook
This package contains a FSAL shared object to
be used with NFS-Ganesha to support LUSTRE via SHOOK.
%endif

# XFS
%if %{with xfs}
%package xfs
Summary: The NFS-GANESHA's XFS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
BuildRequires:	libattr-devel xfsprogs-devel

%description xfs
This package contains a shared object to be used with FSAL_VFS
to support XFS correctly.
%endif

# HPSS
%if %{with hpss}
%package hpss
Summary: The NFS-GANESHA's HPSS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}
#BuildRequires:	hpssfs

%description hpss
This package contains a FSAL shared object to
be used with NFS-Ganesha to support HPSS.
%endif

# PANFS
%if %{with panfs}
%package panfs
Summary: The NFS-GANESHA's PANFS FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}

%description panfs
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PANFS.
%endif

# PT
%if %{with pt}
%package pt
Summary: The NFS-GANESHA's PT FSAL
Group: System/Servers
Requires:	nfs-ganesha = %{version}-%{release}


%description pt
This package contains a FSAL shared object to
be used with NFS-Ganesha to support PT.
%endif

# GLUSTER
%if %{with gluster}
%package gluster
Summary: The NFS-GANESHA's GLUSTER FSAL
Group: System/Servers
Requires:	      nfs-ganesha = %{version}-%{release}
BuildRequires:        pkgconfig(glusterfs-api) >= 3.7.9
#For missing requires in glusterfs-api devel pkg
BuildRequires:        glusterfs-api
BuildRequires:        libattr-devel, libacl-devel

%description gluster
This package contains a FSAL shared object to
be used with NFS-Ganesha to support Gluster.
%endif

%prep
%setup -q -n %{name}-%{version}%{dev_version}
rm -rf contrib/libzfswrapper
%autopatch -p1

%build
cd src && %cmake 					\
	-DBUILD_CONFIG=rpmbuild				\
	-DUSE_FSAL_NULL=%{use_fsal_null}		\
	-DUSE_FSAL_ZFS=OFF				\
	-DUSE_FSAL_XFS=%{use_fsal_xfs}			\
	-DUSE_FSAL_CEPH=%{use_fsal_ceph}		\
	-DUSE_FSAL_LUSTRE=%{use_fsal_lustre}		\
	-DUSE_FSAL_SHOOK=%{use_fsal_shook}		\
	-DUSE_FSAL_GPFS=%{use_fsal_gpfs}		\
	-DUSE_FSAL_HPSS=%{use_fsal_hpss}		\
	-DUSE_FSAL_PANFS=%{use_fsal_panfs}		\
	-DUSE_FSAL_PT=%{use_fsal_pt}			\
	-DUSE_FSAL_GLUSTER=%{use_fsal_gluster}		\
	-DUSE_SYSTEM_NTIRPC=%{use_system_ntirpc}	\
	-DUSE_9P_RDMA=%{use_rdma}			\
	-DUSE_FSAL_LUSTRE_UP=%{use_lustre_up}		\
	-DUSE_LTTNG=%{use_lttng}			\
	-DUSE_ADMIN_TOOLS=%{use_utils}			\
	-DUSE_GUI_ADMIN_TOOLS=%{use_gui_utils}		\
	-DUSE_FSAL_VFS=ON				\
	-DUSE_FSAL_PROXY=ON				\
	-DUSE_DBUS=ON					\
	-DUSE_9P=ON					\
	-DDISTNAME_HAS_GIT_DATA=OFF			\
%if %{with jemalloc}
	-DALLOCATOR=jemalloc
%endif

%make_build

%install
mkdir -p %{buildroot}%{_sysconfdir}/ganesha/
mkdir -p %{buildroot}%{_sysconfdir}/dbus-1/system.d
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/ganesha
mkdir -p %{buildroot}%{_localstatedir}/run/ganesha
cd src
install -m 644 config_samples/logrotate_ganesha	%{buildroot}%{_sysconfdir}/logrotate.d/ganesha
install -m 644 scripts/ganeshactl/org.ganesha.nfsd.conf	%{buildroot}%{_sysconfdir}/dbus-1/system.d
install -m 755 tools/mount.9P	%{buildroot}%{_sbindir}/mount.9P

install -m 644 config_samples/vfs.conf %{buildroot}%{_sysconfdir}/ganesha

mkdir -p %{buildroot}%{_unitdir}
install -m 644 scripts/systemd/nfs-ganesha.service	%{buildroot}%{_unitdir}/nfs-ganesha.service
install -m 644 scripts/systemd/nfs-ganesha-lock.service	%{buildroot}%{_unitdir}/nfs-ganesha-lock.service
install -m 644 scripts/systemd/sysconfig/nfs-ganesha	%{buildroot}%{_sysconfdir}/sysconfig/ganesha

%if %{with pt}
install -m 644 config_samples/pt.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with xfs}
install -m 644 config_samples/xfs.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with ceph}
install -m 644 config_samples/ceph.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with lustre}
install -m 755 config_samples/lustre.conf %{buildroot}%{_sysconfdir}/ganesha
%endif

%if %{with gluster}
install -m 644 config_samples/logrotate_fsal_gluster %{buildroot}%{_sysconfdir}/logrotate.d/ganesha-gfapi
%endif

%if %{with gpfs}
install -m 644 config_samples/gpfs.conf	%{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.nfsd.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.main.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.log.conf %{buildroot}%{_sysconfdir}/ganesha
install -m 644 config_samples/gpfs.ganesha.exports.conf	%{buildroot}%{_sysconfdir}/ganesha
%endif

%make_install -C build

install -m 644 ChangeLog %{buildroot}%{_defaultdocdir}/ganesha

%post
%systemd_post nfs-ganesha
%systemd_post nfs-ganesha-lock

%preun
%systemd_preun nfs-ganesha-lock

%postun
%systemd_postun_with_restart nfs-ganesha-lock


%files
%license src/LICENSE.txt
%{_bindir}/ganesha.nfsd
%if ! %{with system_ntirpc}
%{_libdir}/libntirpc.so.1.3.0
%{_libdir}/libntirpc.so.1.3
%{_libdir}/libntirpc.so
%{_libdir}/pkgconfig/libntirpc.pc
%{_includedir}/ntirpc/
%endif
%config %{_sysconfdir}/dbus-1/system.d/org.ganesha.nfsd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/ganesha
%config(noreplace) %{_sysconfdir}/logrotate.d/ganesha
%dir %{_sysconfdir}/ganesha/
%config(noreplace) %{_sysconfdir}/ganesha/ganesha.conf
%dir %{_defaultdocdir}/ganesha/
%{_defaultdocdir}/ganesha/*


%{_unitdir}/nfs-ganesha.service
%{_unitdir}/nfs-ganesha-lock.service

%files mount-9P
%{_sbindir}/mount.9P


%files vfs
%{_libdir}/ganesha/libfsalvfs*
%config(noreplace) %{_sysconfdir}/ganesha/vfs.conf


%files proxy
%{_libdir}/ganesha/libfsalproxy*

# Optional packages
%if %{with nullfs}
%files nullfs
%{_libdir}/ganesha/libfsalnull*
%endif

%if %{with gpfs}
%files gpfs
%{_libdir}/ganesha/libfsalgpfs*
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.nfsd.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.main.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.log.conf
%config(noreplace) %{_sysconfdir}/ganesha/gpfs.ganesha.exports.conf
%if ! %{with_systemd}
%{_sysconfdir}/init.d/nfs-ganesha-gpfs
%endif
%endif

%if %{with xfs}
%files xfs
%{_libdir}/ganesha/libfsalxfs*
%config(noreplace) %{_sysconfdir}/ganesha/xfs.conf
%endif

%if %{with ceph}
%files ceph
%{_libdir}/ganesha/libfsalceph*
%config(noreplace) %{_sysconfdir}/ganesha/ceph.conf
%endif

%if %{with lustre}
%files lustre
%config(noreplace) %{_sysconfdir}/ganesha/lustre.conf
%{_libdir}/ganesha/libfsallustre*
%endif

%if %{with shook}
%files shook
%{_libdir}/ganesha/libfsalshook*
%endif

%if %{with gluster}
%files gluster
%config(noreplace) %{_sysconfdir}/logrotate.d/ganesha-gfapi
%{_libdir}/ganesha/libfsalgluster*
%endif

%if %{with hpss}
%files hpss
%{_libdir}/ganesha/libfsalhpss*
%endif

%if %{with panfs}
%files panfs
%{_libdir}/ganesha/libfsalpanfs*
%endif

%if %{with pt}
%files pt
%{_libdir}/ganesha/libfsalpt*
%config(noreplace) %{_sysconfdir}/ganesha/pt.conf
%endif

%if %{with lttng}
%files lttng
%{_libdir}/ganesha/libganesha_trace*
%endif

%if %{with utils}
%files utils
%{python2_sitelib}/Ganesha/*
%{python2_sitelib}/ganeshactl-*-info
%if %{with gui_utils}
%{_bindir}/ganesha-admin
%{_bindir}/manage_clients
%{_bindir}/manage_exports
%{_bindir}/manage_logger
%{_bindir}/ganeshactl
%{_bindir}/client_stats_9pOps
%{_bindir}/export_stats_9pOps
%endif
%{_bindir}/fake_recall
%{_bindir}/get_clientids
%{_bindir}/grace_period
%{_bindir}/purge_gids
%{_bindir}/ganesha_stats
%{_bindir}/sm_notify.ganesha
%{_bindir}/ganesha_mgr
%endif



%changelog
* Wed May 03 2017 akien <akien> 2.4.1-3.mga6
+ Revision: 1098907
- Disable gluster module, as glusterfs is being dropped

* Sun Jan 08 2017 daviddavid <daviddavid> 2.4.1-2.mga6
+ Revision: 1080601
- reenable gluster support
- enable ceph support (but not on armv5tl)
- add patch to find properly glusterfs-api

* Fri Dec 16 2016 neoclust <neoclust> 2.4.1-1.mga6
+ Revision: 1075548
- New version 2.4.1
- Rebuild against newer libntirpc

  + akien <akien>
    - rebuild with new libntirpc

* Fri Feb 26 2016 spuhler <spuhler> 2.3.0-5.mga6
+ Revision: 979714
- rebuild with new libntirpc

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Thu Nov 19 2015 daviddavid <daviddavid> 2.3.0-3.mga6
+ Revision: 904208
- rebuild for new jemalloc 4.0.4

* Fri Nov 06 2015 spuhler <spuhler> 2.3.0-2.mga6
+ Revision: 898300
- fixed Requires: python-gobject

* Fri Oct 30 2015 spuhler <spuhler> 2.3.0-1.mga6
+ Revision: 896804
- removed %%dir %%{_localstatedir}/run/ganesha
  * we don't need it
- fixed BuildRequires: pkgconfig(libntirpc)
- cleanup spec
- upgrade src to rel version (from RC7)
- imported package nfs-ganesha

